@@ -19,9 +19,8 @@ app = Flask(__name__)
 # })
 
 kable = Kable({
-    "client_id": 'kci_75bfe76dea214218be408fe6fa241f07',
-    "client_secret": 'sk_test.jjrhHXZL.XdSSvBt22dKQdmMvjpiQ9F9v1DGtw26h',
-    "environment": 'TEST',
+    "kable_client_id": 'kci_75bfe76dea214218be408fe6fa241f07',
+    "kable_client_secret": 'sk_test.jjrhHXZL.XdSSvBt22dKQdmMvjpiQ9F9v1DGtw26h',
     "base_url": 'https://test.kable.io',
     "debug": True,
     # "record_authentication": False,
@@ -30,15 +29,25 @@ kable = Kable({
 })
 
 
-@app.route('/authenticate/<string:path>')
+@app.route('/hi')
+def hi():
+    return "hi world - nothing"
+
+
+@app.route('/authenticate')
 @kable.authenticate
-def authenticated(path):
-    print(path)
+def authenticated():
     return "hello world - authenticate"
 
+# @app.route('/authenticate/<string:path>')
+# @kable.authenticate
+# def authenticatedWithPath(path):
+#     print(path)
+#     return "hello world - authenticate path"
+
 @app.route('/record')
 def recordData():
-    kable.record({"userId": "USER", "clientId": "test_company_1"})
+    kable.record({"userId": "flask", "clientId": "test_company_1"})
     return "hello world - record data"
 
 
